@@ -76,10 +76,6 @@ class Page(WikiTextHtml):
         return postprocess.replace(self, wtp.string)
 
     def render(self, body: str = None) -> "Page":
-        if not self.page_exists(self._page):
-            self._html = f"<h2>Page {self._page} not found</h2>"
-            return self
-
         body = self.page_load(self._page)
         wtp = self.prepare(body)
         self._html = self.render_page(wtp)
